new;
/****************************************************************************
This file merges the county and national data in a panel/longitudinal format
for estimation.  This file produces seven output files corresponding to seven
samples based on the available data by year and county.  The samples are 
explained below at the bottom of the code.
*****************************************************************************/


loadm sp[] = hprices.txt;
loadm sq[] = dates.txt;
loadm sw[] = aggregatedata.txt;
/*sw variable order: Date; CPI_Allitems; CPI_core; Fedfunds; IP; Mortgage Rate; Spot Oil*/
loadm cp[] = cpiwestregion.txt;
loadm ur[] = unemploymentrate.txt;
loadm pp[] = populationvector.out;
loadm hs[] = newhouses.txt;
/*CPI_West Region and County Unemployment rates are NOT seasonally adjusted*/

sp = reshape(sp,rows(sp)/14,14);
sq = reshape(sq,rows(sq)/1,1);
sw = reshape(sw,rows(sw)/7,7);
cp = reshape(cp,rows(cp)/3,3);
ur = reshape(ur,rows(ur)/14,14);
pp = reshape(pp,rows(pp)/1,1);
hs = reshape(hs,rows(hs)/14,14);
format /ld 10,5;
outwidth 256;


/*cut sq to end with 2002*/
sq = sq[1:(rows(sq)-24),.];
sq = sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq|sq;


/*Get rid of early years for unemployment, 1983 through 1990*/
ur1 = delif(ur, ur[.,2] .lt 1991);
ur = ur1;

/*Get rid some years, 1988 through 1990; 2003 and 2004*/
hs1 = delif(hs, hs[.,2] .lt 1991);
hs1 = delif(hs1, hs1[.,2] .gt 2002);
hs = hs1;



/*reshape the files to have the months in time series form*/
hp = sp';
ur = ur';
hs = hs';


/*remove the region and year identifier (to be added back later)*/
hp = hp[3:14,.];
ur = ur[3:14,.];
hs = hs[3:14,.];

/*vec will stack the columns to form a time series vector*/
vhp = vec(hp);
vur = vec(ur);
vhs = vec(hs);

/*Create a time dummy matrix, 144x144*/
td = eye(144);
td = td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td|td;

/*Create a time trend, 144x1*/
tme = zeros(144,1);
i=1;
do while i le 144;
	tme[i,1] = i;
i=i+1;
endo;
tme = tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme|tme;


/*Note the Counties are ordered as follows*/
@1: Alameda County@
@2: Conta Costa County@
@3: El Dorado County@
@4: Fresno County@
@5: Kern County@
@6: Los AngelesCounty@
@7: Madera County@
@8: Marin County@
@9: Merced County@
@10: Monterey County@
@11: Napa County@
@12: Nevada County@
@13: Orange County@
@14: Placer County@
@15: Riverside County@
@16: Sacramento County@
@17: San Benito County@
@18: San Diego County@
@19: San Francisco County@
@20: San Joaquin County@
@21: San Luis Obispo County@
@22: San Mateo County@
@23: Santa Barbara County@
@24: Santa Clara County@
@25: Santa Cruz County@
@26: Solano County@
@27: Sonoma County@
@28: Stanislaus County@
@29: Tulare County@
@30: Ventura County@
@31: Yolo County@

/*Create a vector to identify the county*/
cc1 = zeros(144,1);
i=1;
do while i le 144;
	cc1[i,1] = 1;
i=i+1;
endo;

cc2 = zeros(144,1);
i=1;
do while i le 144;
	cc2[i,1] = 2;
i=i+1;
endo;

cc3 = zeros(144,1);
i=1;
do while i le 144;
	cc3[i,1] = 3;
i=i+1;
endo;

cc4 = zeros(144,1);
i=1;
do while i le 144;
	cc4[i,1] = 4;
i=i+1;
endo;

cc5 = zeros(144,1);
i=1;
do while i le 144;
	cc5[i,1] = 5;
i=i+1;
endo;

cc6 = zeros(144,1);
i=1;
do while i le 144;
	cc6[i,1] = 6;
i=i+1;
endo;

cc7 = zeros(144,1);
i=1;
do while i le 144;
	cc7[i,1] = 7;
i=i+1;
endo;

cc8 = zeros(144,1);
i=1;
do while i le 144;
	cc8[i,1] = 8;
i=i+1;
endo;

cc9 = zeros(144,1);
i=1;
do while i le 144;
	cc9[i,1] = 9;
i=i+1;
endo;

cc10 = zeros(144,1);
i=1;
do while i le 144;
	cc10[i,1] = 10;
i=i+1;
endo;

cc11 = zeros(144,1);
i=1;
do while i le 144;
	cc11[i,1] = 11;
i=i+1;
endo;

cc12 = zeros(144,1);
i=1;
do while i le 144;
	cc12[i,1] = 12;
i=i+1;
endo;

cc13 = zeros(144,1);
i=1;
do while i le 144;
	cc13[i,1] = 13;
i=i+1;
endo;

cc14 = zeros(144,1);
i=1;
do while i le 144;
	cc14[i,1] = 14;
i=i+1;
endo;

cc15 = zeros(144,1);
i=1;
do while i le 144;
	cc15[i,1] = 15;
i=i+1;
endo;

cc16 = zeros(144,1);
i=1;
do while i le 144;
	cc16[i,1] = 16;
i=i+1;
endo;

cc17 = zeros(144,1);
i=1;
do while i le 144;
	cc17[i,1] = 17;
i=i+1;
endo;

cc18 = zeros(144,1);
i=1;
do while i le 144;
	cc18[i,1] = 18;
i=i+1;
endo;

cc19 = zeros(144,1);
i=1;
do while i le 144;
	cc19[i,1] = 19;
i=i+1;
endo;

cc20 = zeros(144,1);
i=1;
do while i le 144;
	cc20[i,1] = 20;
i=i+1;
endo;

cc21 = zeros(144,1);
i=1;
do while i le 144;
	cc21[i,1] = 21;
i=i+1;
endo;

cc22 = zeros(144,1);
i=1;
do while i le 144;
	cc22[i,1] = 22;
i=i+1;
endo;

cc23 = zeros(144,1);
i=1;
do while i le 144;
	cc23[i,1] = 23;
i=i+1;
endo;

cc24 = zeros(144,1);
i=1;
do while i le 144;
	cc24[i,1] = 24;
i=i+1;
endo;

cc25 = zeros(144,1);
i=1;
do while i le 144;
	cc25[i,1] = 25;
i=i+1;
endo;

cc26 = zeros(144,1);
i=1;
do while i le 144;
	cc26[i,1] = 26;
i=i+1;
endo;

cc27 = zeros(144,1);
i=1;
do while i le 144;
	cc27[i,1] = 27;
i=i+1;
endo;

cc28 = zeros(144,1);
i=1;
do while i le 144;
	cc28[i,1] = 28;
i=i+1;
endo;

cc29 = zeros(144,1);
i=1;
do while i le 144;
	cc29[i,1] = 29;
i=i+1;
endo;

cc30 = zeros(144,1);
i=1;
do while i le 144;
	cc30[i,1] = 30;
i=i+1;
endo;

cc31 = zeros(144,1);
i=1;
do while i le 144;
	cc31[i,1] = 31;
i=i+1;
endo;

cn = cc1|cc2|cc3|cc4|cc5|cc6|cc7|cc8|cc9|cc10|cc11|cc12|cc13|cc14|cc15|cc16|cc17|cc18|cc19|cc20|cc21|cc22|cc23|cc24|cc25|cc26|cc27|cc28|cc29|cc30|cc31;


/*Merge housing data with aggregate data*/
sw = sw[133:276,.];
sw = sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw|sw;
cp = cp[49:192,.];
cp = cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp|cp;
inf = cp[.,3];

/*deflate housing prices using CPI_West*/

vhp = sq~vhp;
cp = cp[.,1]~cp[.,2]/100;
vhr = zeros(rows(vhp),1);

i=1; j=1;
do while j le rows(vhp);
do while i le rows(cp);			
	if cp[i,1]==vhp[j,1];
	vhr[j,1]=vhp[j,2]/cp[i,2];
	endif;
i=i+1;
endo;
j=j+1;
i=1;
endo;

vhp = vhr;
cp = cp*100;


/*log the following: housing prices, newhouses, population(?)*/
vhp = ln(vhp);
vhs = ln(vhs);


/*Merge the dates with the data*/
vhp = cn~sq~vhp~vur~cp[.,2]~inf~sw[.,2:cols(sw)]~vhs~pp~td~tme;
/*Variable order: County Identifier; Date; Housing Prices; County Unemployment Rate;
CPIWestRegion; inflation rate; CPI_Allitems; CPI_core; Fedfunds; IP; Mortgage Rate; Spot Oil; construction; population*/



/*Sample 1: Remove San Luis Obispo and restrict to 1990507-200212*/
output file= housingprices_sample1.out reset;

vhp0 = delif(vhp, vhp[.,1] .eq 21);
vhp1 = delif(vhp0, vhp0[.,2] .lt 199507);
/*Sample size now = 2700*/
vhp1;


/*Sample 2: Only counties 199101-200212; includes: 1,2,4,5,13,15,18,24,30*/
output file= housingprices_sample2.out reset;

vhp1 = selif(vhp, (vhp[.,1] .eq 1) .or (vhp[.,1] .eq 2) .or (vhp[.,1] .eq 4) .or (vhp[.,1] .eq 5) .or (vhp[.,1] .eq 13) .or (vhp[.,1] .eq 15) .or (vhp[.,1] .eq 18) .or (vhp[.,1] .eq 24) .or (vhp[.,1] .eq 30));
/*Sample size now = 1296*/
vhp1;


/*Sample 3: Add Cn 6 (only missing 1991) to Sample 2*/
output file= housingprices_sample3.out reset;

vhp0 = selif(vhp, (vhp[.,1] .eq 1) .or (vhp[.,1] .eq 2) .or (vhp[.,1] .eq 4) .or (vhp[.,1] .eq 5) .or (vhp[.,1] .eq 13) .or (vhp[.,1] .eq 15) .or (vhp[.,1] .eq 18) .or (vhp[.,1] .eq 24) .or (vhp[.,1] .eq 30) .or (vhp[.,1] .eq 6));
vhp1 = delif(vhp0, vhp0[.,2] .lt 199201);
/*sample size now = 1320*/
vhp1;


/*Sample 4: Add Cn 3,14 (missing 1991, 1992) to Sample 3*/
output file= housingprices_sample4.out reset;

vhp0 = selif(vhp, (vhp[.,1] .eq 1) .or (vhp[.,1] .eq 2) .or (vhp[.,1] .eq 4) .or (vhp[.,1] .eq 5) .or (vhp[.,1] .eq 13) .or (vhp[.,1] .eq 15) .or (vhp[.,1] .eq 18) .or (vhp[.,1] .eq 24) .or (vhp[.,1] .eq 30) .or (vhp[.,1] .eq 6) .or (vhp[.,1] .eq 3) .or (vhp[.,1] .eq 14));
vhp1 = delif(vhp0, vhp0[.,2] .lt 199301);
/*sample size now = 1440*/
vhp1;


/*Sample 5: All Counties from 1998:04 to 200212*/
output file= housingprices_sample5.out reset;

vhp1 = delif(vhp, vhp[.,2] .lt 199804);
/*sample size now = 1767*/
vhp1;


/*Sample 6_"Southern California: Counties: 23,21,5,6,15,18,13,30 from 1998:04 to 200212*/
output file= housingprices_SoCAL_sample6.out reset;

vhp0 = selif(vhp, (vhp[.,1] .eq 23) .or (vhp[.,1] .eq 21) .or (vhp[.,1] .eq 5) .or (vhp[.,1] .eq 6) .or (vhp[.,1] .eq 15) .or (vhp[.,1] .eq 18) .or (vhp[.,1] .eq 13) .or (vhp[.,1] .eq 30));
vhp1 = delif(vhp0, vhp0[.,2] .lt 199804);
/*sample size now = 456*/
vhp1;



/*Sample 7_"Northern California: Counties: Everything but => 23,21,5,6,15,18,13,30 from 1995:07 to 200212*/
output file= housingprices_NoCAL_sample7.out reset;

vhp0 = delif(vhp, (vhp[.,1] .eq 23) .or (vhp[.,1] .eq 21) .or (vhp[.,1] .eq 5) .or (vhp[.,1] .eq 6) .or (vhp[.,1] .eq 15) .or (vhp[.,1] .eq 18) .or (vhp[.,1] .eq 13) .or (vhp[.,1] .eq 30));
vhp1 = delif(vhp0, vhp0[.,2] .lt 199507);
/*sample size now = 2070*/
vhp1;


